{ config, pkgs, ... }:
{
    imports = [
        ./gitea.nix
    ];

    boot.loader.grub.enable = true;
    boot.loader.grub.version = 2;
    boot.loader.grub.device = "/dev/vda";

    networking.hostName = "Emitter";

    networking.useDHCP = false;
    networking.interfaces.ens3.useDHCP = true;

    i18n.defaultLocale = "de_DE.UTF-8";
    console.keyMap = "de";

    services.openssh.ports = [ 8248 ];
    networking.firewall.allowedTCPPorts = [ 8248 ];

    nix.settings.trusted-users = [ "fruchti" ];
    security.sudo.wheelNeedsPassword = false;

    security.acme = {
        defaults = {
            email = config.email.adminEmail;
        };
        acceptTerms = true;
    };

    system.autoUpgrade = {
        enable = true;
        allowReboot = true;
        sendEmail = true;
        gitPull = true;
        gitUser = "fruchti";
    };


    nixpkgs.overlays = [
        (self: super: {
            burp = (super.burp.overrideAttrs (old: {
                postInstall = ''
                    mv $out/sbin/burp $out/sbin/burp-untunneled
                    cat > $out/sbin/burp <<-EOF
                    #!/${pkgs.bash}/bin/bash
                    ${pkgs.openssh}/bin/ssh -i /secrets/id_burp_remote -o IdentitiesOnly=yes -o ExitOnForwardFailure=yes -L 4971:localhost:4971 burp-remote@rupert.gvfr.de -f true
                    $out/sbin/burp-untunneled \$@
                    EOF
                    chmod +x $out/sbin/burp
                '';
            }));
        })
    ];

    services.burp = {
        client = {
            enable = true;
            # Because of the port forward, the server will be localhost
            server = "localhost";
            frequency = "2:00";
            passwordFile = "/secrets/burp_client_password";
            sslKeyPasswordFile = "/secrets/burp_ssl_key_password";
        };
    };

    # This value determines the NixOS release from which the default
    # settings for stateful data, like file locations and database versions
    # on your system were taken. It’s perfectly fine and recommended to leave
    # this value at the release version of the first install of this system.
    # Before changing this value read the documentation for this option
    # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
    system.stateVersion = "21.11"; # Did you read the comment?
}

